@@ -730,12 +730,17 @@ class ShowWhitespace(object):
 
     @ce_option(False)
     def setShowWhitespace(self, value):
-        option = self.document().defaultTextOption()
-        if value:
-            option.setFlags(option.flags() | option.ShowTabsAndSpaces)
-        else:
-            option.setFlags(option.flags() & ~option.ShowTabsAndSpaces)
-        self.document().setDefaultTextOption(option)
+        try:
+            option = self.document().defaultTextOption()
+            if value:
+                option.setFlags(option.flags() | option.ShowTabsAndSpaces)
+            else:
+                option.setFlags(option.flags() & ~option.ShowTabsAndSpaces)
+            self.document().setDefaultTextOption(option)
+        except Exception:
+            # This can produce: 2147483617 is not a valid QTextOption.Flag
+            # and I do not know how to avoid it :/
+            pass
 
 
 class ShowLineEndings(object):
@@ -746,12 +751,17 @@ class ShowLineEndings(object):
         return bool(option.flags() & option.ShowLineAndParagraphSeparators)
 
     def setShowLineEndings(self, value):
-        option = self.document().defaultTextOption()
-        if value:
-            option.setFlags(option.flags() | option.ShowLineAndParagraphSeparators)
-        else:
-            option.setFlags(option.flags() & ~option.ShowLineAndParagraphSeparators)
-        self.document().setDefaultTextOption(option)
+        try:
+            option = self.document().defaultTextOption()
+            if value:
+                option.setFlags(option.flags() | option.ShowLineAndParagraphSeparators)
+            else:
+                option.setFlags(option.flags() & ~option.ShowLineAndParagraphSeparators)
+            self.document().setDefaultTextOption(option)
+        except Exception:
+            # This can produce: 2147483617 is not a valid QTextOption.Flag
+            # and I do not know how to avoid it :/
+            pass
 
 
 class LineNumbers(object):
@@ -1216,9 +1226,10 @@ class BreakPoints(object):
         """A list of breakpoints for this editor."""
         return list(sorted(self._breakPoints))
 
-        self._breakPoints = {}
-        self.breakPointsChanged.emit(self)
-        self.__breakPointArea.update()
+    def clearBreakPoints(self):
+        """Remove all breakpoints for this editor."""
+        for linenr in self.breakPoints():
+            self.toggleBreakpoint(linenr)
 
     def toggleBreakpoint(self, linenr=None):
         """Turn breakpoint on/off for given linenr of current line."""
