@@ -592,11 +592,15 @@ class PyzoInterpreter:
             # IPython wraps std streams just like we do below, but
             # pyreadline adds *another* wrapper, which is where it
             # goes wrong. Here we set it back to bypass pyreadline.
-            from IPython.utils import io
 
-            io.stdin = io.IOStream(sys.stdin)
-            io.stdout = io.IOStream(sys.stdout)
-            io.stderr = io.IOStream(sys.stderr)
+            if IPython.version_info < (
+                8,
+            ):  # corrects a problem with IOStream from IPython 8.x.x
+                from IPython.utils import io
+
+                io.stdin = io.IOStream(sys.stdin)
+                io.stdout = io.IOStream(sys.stdout)
+                io.stderr = io.IOStream(sys.stderr)
 
             # Ipython uses msvcrt e.g. for pausing between pages
             # but this does not work in pyzo
@@ -874,6 +878,10 @@ class PyzoInterpreter:
             if self._ipython:
                 self._ipython.execution_count += 1
 
+        # Bring fname to the canonical form so that pdb recognizes the breakpoints,
+        # otherwise filename r"C:\..." would be different from canonical form r"c:\..."
+        fname = self.debugger.canonic(fname)
+
         # Put the line number in the filename (if necessary)
         # Note that we could store the line offset in the _codeCollection,
         # but then we cannot retrieve it for syntax errors.
